"use client";

import React, { useState, useEffect } from 'react';
import { motion, AnimatePresence } from 'framer-motion';
import Head from 'next/head'; // Import Head for SEO
import Link from 'next/link';
import { FaStar } from 'react-icons/fa';
import AdSense from '@/app/components/AdSense';

interface MediaItem {
  id: number;
  title?: string;
  name?: string;
  poster_path: string | null;
  vote_average: number;
  media_type: 'movie' | 'tv';
}

const SearchPage: React.FC = () => {
  const [query, setQuery] = useState("");
  const [results, setResults] = useState<MediaItem[]>([]);
  const [latestItems, setLatestItems] = useState<MediaItem[]>([]);
  const [itemsToShow, setItemsToShow] = useState(40); // Default to 40 items

  useEffect(() => {
    const calculateItemsToShow = () => {
      const screenWidth = window.innerWidth;
      if (screenWidth >= 1024) {
        setItemsToShow(40); // 40 items for PC
      } else {
        setItemsToShow(21); // 21 items for mobile
      }
    };

    calculateItemsToShow();
    window.addEventListener('resize', calculateItemsToShow);

    return () => {
      window.removeEventListener('resize', calculateItemsToShow);
    };
  }, []);

  useEffect(() => {
    const fetchLatestItems = async () => {
      let fetchedItems: MediaItem[] = [];
      let page = 1;

      try {
        while (fetchedItems.length < itemsToShow) {
          const response = await fetch(
            `https://api.themoviedb.org/3/trending/all/day?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&page=${page}`
          );
          const data = await response.json();
          const filteredData = data.results.filter((item: any) => item.vote_average > 0);

          fetchedItems = [...fetchedItems, ...filteredData];
          page += 1;

          if (data.results.length === 0) break; // Break if no more results
        }
      } catch (error) {
        console.error('Failed to fetch latest items:', error);
      }

      setLatestItems(fetchedItems.slice(0, itemsToShow));
    };

    fetchLatestItems();
  }, [itemsToShow]);

  useEffect(() => {
    const fetchResults = async () => {
      let fetchedItems: MediaItem[] = [];
      let page = 1;

      try {
        while (fetchedItems.length < itemsToShow) {
          const response = await fetch(
            `https://api.themoviedb.org/3/search/multi?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&query=${query}&page=${page}`
          );
          const data = await response.json();
          const filteredData = data.results.filter((item: any) => item.vote_average > 0);

          fetchedItems = [...fetchedItems, ...filteredData];
          page += 1;

          if (data.results.length === 0) break; // Break if no more results
        }
      } catch (error) {
        console.error('Failed to fetch search results:', error);
      }

      setResults(fetchedItems.slice(0, itemsToShow));
    };

    if (query.length > 0) {
      fetchResults();
    }
  }, [query, itemsToShow]);

  const handleSearchChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setQuery(e.target.value);
  };

  const displayedItems = query.length > 0 ? results : latestItems;

  const pageTitle = query.length > 0 
    ? `Search Results for "${query}" - Delgor` 
    : "Trending Movies & TV Shows - Delgor";
  
  const pageDescription = query.length > 0 
    ? `Find movies, TV shows, and more related to "${query}" on Delgor.` 
    : "Check out the trending movies and TV shows on Delgor, your ultimate platform for streaming content.";

  return (
    <>
      <Head>
        <title>{pageTitle}</title>
        <meta name="description" content={pageDescription} />
        <link rel="canonical" href="https://www.delgor.com/search" />
        <meta property="og:title" content={pageTitle} />
        <meta property="og:description" content={pageDescription} />
        <meta property="og:url" content="https://www.delgor.com/search" />
        <meta property="og:type" content="website" />
        <meta property="og:image" content="https://www.delgor.com/images/og-image.jpg" /> {/* Adjust the OG image */}
      </Head>

      <div className="p-4">
        <motion.div
          className="relative z-10 flex justify-center items-center mt-4 md:mt-16 lg:mt-24 w-full"  // Centering adjustments
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.5, delay: 0.3 }}
        >
          <input
            type="text"
            value={query}
            onChange={handleSearchChange}
            placeholder="Search for movies or TV series..."
            className="w-[90%] lg:w-[70%] px-4 py-2 rounded-lg border-2 border-red-600 focus:outline-none text-black"
          />
        </motion.div>

        <div className="mt-4 grid grid-cols-3 sm:grid-cols-3 md:grid-cols-5 lg:grid-cols-8 gap-4">
          <AnimatePresence>
            {displayedItems.map((item, index) => {
              const title = item.title || item.name || "Untitled";
              const slug = `${item.id}-${title}`.toLowerCase().replace(/ /g, '-');
              const mediaType = item.media_type === 'movie' ? 'movie' : 'tv';

              return (
                <motion.div
                  key={item.id}
                  className="relative"
                  initial={{ opacity: 0, scale: 0.8 }}
                  animate={{ opacity: 1, scale: 1 }}
                  exit={{ opacity: 0, scale: 0.8 }}
                  transition={{ duration: 0.3, delay: index * 0.05 }}
                >
                  <Link href={`/watch/${mediaType}?slug=${slug}`} passHref>
                    <div
                      className="relative bg-cover bg-center rounded-lg overflow-hidden shadow-lg hover:scale-105 transition-transform duration-300 ease-in-out cursor-pointer"
                      style={{
                        backgroundImage: item.poster_path
                          ? `url(https://image.tmdb.org/t/p/w500${item.poster_path})`
                          : 'url(/images/fall-back.jpg)',
                        paddingBottom: '150%',
                      }}
                    >
                      <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-yellow-400 text-xs px-2 py-1 rounded flex items-center">
                        <FaStar className="mr-1" />
                        {item.vote_average.toFixed(1)}
                      </div>
                    </div>
                  </Link>
                </motion.div>
              );
            })}
          </AnimatePresence>
        </div>
        <div className="my-8">
        {/* AdSense Ad between Sliders */}
        <div className="my-8 w-full">
          <AdSense />
        </div>
        </div>
      </div>
    </>
  );
};

export default SearchPage;
